PRO RH1001, LIMITS, HEADER, IUN, IOERR
;
;  Procedure to read file header info for FFI 1001 and return info in
;  structure HEADER.
;
;Input:
;  IUN    = Logical unit number for ASCII exchange file.
;           Assume file has already been opened for reading.
;  LIMITS = Structure defined in DATAEX_LIM_DEF.PRO
;
;Output:
;  HEADER = Structure containing file header info.
;           Variable names used in HEADER are similar to those defined in the 
;           document "Format Specification For Data Exchange".
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-06-28 (SEG) Written.
;
IOERR = 0
ON_IOERROR, END_OF_FILE
NIV  = 1                                     ; # independent variables.
;
;  Define stucture HEADER.
;
HEADER = { HEADER_1001,                    $ ; Structure name.
           NIV:     NIV,                   $ ; # independent variables.
           NLHEAD:  0,                     $ ; # lines in file header.
           FFI:     1001,                  $ ; File Format Index.
           ONAME:   '',                    $ ; Originator's name.
           ORG:     '',                    $ ; Originator's organization.
           SNAME:   '',                    $ ; Data source.
           MNAME:   '',                    $ ; Mission name.
           IVOL:    0,                     $ ; Dataset volume number.
           NVOL:    0,                     $ ; Total # dataset volumes.
           DATE:    INTARR(3),             $ ; UT date of data (yyyy mm dd).
           RDATE:   INTARR(3),             $ ; Data revision date (yyyy mm dd).
           DX:      FLTARR(NIV),           $ ; Independent variable intervals.
;           NX:      INTARR(NIV),           $ ; # values for each indep. var.
           NX:      LONARR(NIV),           $ ; # values for each indep. var.
           XNAME:   STRARR(NIV),           $ ; Indep. var. names.
           NV:      0,                     $ ; # primary variables.
           VSCAL:   FLTARR(LIMITS.MAXV),   $ ; Scale factors for prim. vars.
           VMISS:   FLTARR(LIMITS.MAXV),   $ ; Missing values for prim. vars.
           VNAME:   STRARR(LIMITS.MAXV),   $ ; Primary var. names.
           NSCOML:  0,                     $ ; # special comment line.
           SCOM:    STRARR(LIMITS.MAXCOM), $ ; Special comments.
           NNCOML:  0,                     $ ; # normal comment lines.
           NCOM:    STRARR(LIMITS.MAXCOM)  $ ; Normal comments.
         }
;
;  Read file header values and store them in HEADER.
;  Error checks are only to ensure that subscripted variables do not
;  exceed bounds defined in HEADER.
;
POINT_LUN, IUN, 0		; Position IUN to the beginning of the file.
I = INTARR(2)
READF, IUN, I		&	HEADER.NLHEAD = I(0)
				HEADER.FFI    = I(1)
C = ''
READF, IUN, C		&	HEADER.ONAME = C
READF, IUN, C		&	HEADER.ORG = C
READF, IUN, C		&	HEADER.SNAME = C
READF, IUN, C		&	HEADER.MNAME = C
I = INTARR(2)
READF, IUN, I		&	HEADER.IVOL = I(0)
                                HEADER.NVOL = I(1)
I = INTARR(6)
READF, IUN, I		&	HEADER.DATE  = I(0:2)
                                HEADER.RDATE = I(3:5)
F = 0.0
READF, IUN, F		&	HEADER.DX(0) = F
READF, IUN, C		&	HEADER.XNAME(0) = C
I = 0
READF, IUN, I		&	HEADER.NV = I
;
IF HEADER.NV LT 1 OR HEADER.NV GT LIMITS.MAXV THEN BEGIN
  STATUS = FSTAT( IUN )
  STOP, '%% Bad value for NV in file ', STATUS.NAME
ENDIF
;
F = FLTARR(HEADER.NV)
READF, IUN, F		&	HEADER.VSCAL = F
READF, IUN, F		&	HEADER.VMISS = F
;
;  Read VNAME and scale missing values.
;
FOR J=0,HEADER.NV-1 DO BEGIN
  HEADER.VMISS(J) = HEADER.VSCAL(J) * HEADER.VMISS(J)
  READF, IUN, C		&	HEADER.VNAME(J) = C
ENDFOR
I = 0
READF, IUN, I		&	HEADER.NSCOML = I
;
IF HEADER.NSCOML LT 0 OR HEADER.NSCOML GT LIMITS.MAXCOM THEN BEGIN
  STATUS = FSTAT( IUN )
  STOP, '%% Bad value for NSCOML in file ', STATUS.NAME
ENDIF
;
FOR J=0,HEADER.NSCOML-1 DO BEGIN
  READF, IUN, C		&	HEADER.SCOM(J) = C
ENDFOR
READF, IUN, I		&	HEADER.NNCOML = I
;
IF HEADER.NNCOML LT 0 OR HEADER.NNCOML GT LIMITS.MAXCOM THEN BEGIN
  STATUS = FSTAT( IUN )
  STOP, '%% Bad value for NNCOML in file ', STATUS.NAME
ENDIF
;
FOR J=0,HEADER.NNCOML-1 DO BEGIN
  READF, IUN, C		&	HEADER.NCOM(J) = C
ENDFOR
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
